diff --git a/NKC_WF/NKC_WF.csproj b/NKC_WF/NKC_WF.csproj
index 6ae29c9..b501f35 100644
--- a/NKC_WF/NKC_WF.csproj
+++ b/NKC_WF/NKC_WF.csproj
@@ -393,6 +393,7 @@
+
@@ -914,6 +915,13 @@
cmp_kitReqSched.ascx
+
+ cmp_kitRunning.ascx
+ ASPXCodeBehind
+
+
+ cmp_kitRunning.ascx
+
cmp_kitting.ascx
ASPXCodeBehind
diff --git a/NKC_WF/WebUserControls/cmp_kitRunning.ascx b/NKC_WF/WebUserControls/cmp_kitRunning.ascx
new file mode 100644
index 0000000..24d2265
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_kitRunning.ascx
@@ -0,0 +1,37 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_kitRunning.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_kitRunning" %>
+
+
+<%--
+
+
+
+
+
+ <%# traduci("NoKitReqRunning") %>
+
+
+
+
+
+
+
+
+
+
+
+
+
+--%>
+
+
+
+
+
+
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_kitRunning.ascx.cs b/NKC_WF/WebUserControls/cmp_kitRunning.ascx.cs
new file mode 100644
index 0000000..802abf1
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_kitRunning.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_kitRunning : BaseUserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_kitRunning.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_kitRunning.ascx.designer.cs
new file mode 100644
index 0000000..835f1c6
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_kitRunning.ascx.designer.cs
@@ -0,0 +1,35 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_kitRunning
+ {
+
+ ///
+ /// Controllo frmView.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.FormView frmView;
+
+ ///
+ /// Controllo odsKit.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.ObjectDataSource odsKit;
+ }
+}
diff --git a/NKC_WF/site/Kitting.aspx b/NKC_WF/site/Kitting.aspx
index 86470d4..3f604ee 100644
--- a/NKC_WF/site/Kitting.aspx
+++ b/NKC_WF/site/Kitting.aspx
@@ -1,9 +1,13 @@
-<%@ Page Title="" Language="C#" MasterPageFile="~/Site.master" AutoEventWireup="true" CodeBehind="Kitting.aspx.cs" Inherits="NKC_WF.Kitting" %>
+<%@ Page Title="" Language="C#" MasterPageFile="~/Site.master" AutoEventWireup="true" CodeBehind="Kitting.aspx.cs" Inherits="NKC_WF.site.Kitting" %>
<%@ Register Src="~/WebUserControls/cmp_kitting.ascx" TagPrefix="uc1" TagName="cmp_kitting" %>
+<%@ Register Src="~/WebUserControls/cmp_kitRunning.ascx" TagPrefix="uc1" TagName="cmp_kitRunning" %>
+
+
-
-
-
+
+
+
+
diff --git a/NKC_WF/site/Kitting.aspx.cs b/NKC_WF/site/Kitting.aspx.cs
index 025a43b..0f0c419 100644
--- a/NKC_WF/site/Kitting.aspx.cs
+++ b/NKC_WF/site/Kitting.aspx.cs
@@ -1,7 +1,7 @@
using System;
using System.Web.UI;
-namespace NKC_WF
+namespace NKC_WF.site
{
public partial class Kitting : System.Web.UI.Page
{
diff --git a/NKC_WF/site/KittingSmart.aspx b/NKC_WF/site/KittingSmart.aspx
index 5cc652c..82d49a7 100644
--- a/NKC_WF/site/KittingSmart.aspx
+++ b/NKC_WF/site/KittingSmart.aspx
@@ -1,11 +1,13 @@
-<%@ Page Title="" Language="C#" MasterPageFile="~/Site.Master" AutoEventWireup="true" CodeBehind="KittingSmart.aspx.cs" Inherits="NKC_WF.site.KittingSmart" %>
+<%@ Page Title="" Language="C#" MasterPageFile="~/Site.master" AutoEventWireup="true" CodeBehind="KittingSmart.aspx.cs" Inherits="NKC_WF.site.KittingSmart" %>
<%@ Register Src="~/WebUserControls/cmp_kittingSmart.ascx" TagPrefix="uc1" TagName="cmp_kittingSmart" %>
-
-
+<%@ Register Src="~/WebUserControls/cmp_kitRunning.ascx" TagPrefix="uc1" TagName="cmp_kitRunning" %>
-
-
+
diff --git a/NKC_WF/site/Kitting.aspx.designer.cs b/NKC_WF/site/Kitting.aspx.designer.cs
index 4ed15a3..4f517a0 100644
--- a/NKC_WF/site/Kitting.aspx.designer.cs
+++ b/NKC_WF/site/Kitting.aspx.designer.cs
@@ -7,20 +7,29 @@
//
//------------------------------------------------------------------------------
-namespace NKC_WF
+namespace NKC_WF.site
{
- public partial class Kitting
- {
+ public partial class Kitting
+ {
- ///
- /// Controllo cmp_kitting.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::NKC_WF.WebUserControls.cmp_kitting cmp_kitting;
- }
+ ///
+ /// Controllo cmp_kitRunning.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_kitRunning cmp_kitRunning;
+
+ ///
+ /// Controllo cmp_kitting.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_kitting cmp_kitting;
+ }
}
diff --git a/NKC_WF/site/KittingSmart.aspx.designer.cs b/NKC_WF/site/KittingSmart.aspx.designer.cs
index 94972ac..4e0c344 100644
--- a/NKC_WF/site/KittingSmart.aspx.designer.cs
+++ b/NKC_WF/site/KittingSmart.aspx.designer.cs
@@ -11,25 +11,34 @@ namespace NKC_WF.site
{
- public partial class KittingSmart
- {
+ public partial class KittingSmart
+ {
- ///
- /// Controllo hfBatchID.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
+ ///
+ /// Controllo hfBatchID.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
- ///
- /// Controllo cmp_kittingSmart.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::NKC_WF.WebUserControls.cmp_kittingSmart cmp_kittingSmart;
- }
+ ///
+ /// Controllo cmp_kitRunning.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_kitRunning cmp_kitRunning;
+
+ ///
+ /// Controllo cmp_kittingSmart.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_kittingSmart cmp_kittingSmart;
+ }
}